==> cri-o-1.19.0-7-aarch64.pkg.tar.xz: usr/share/doc/cri-o/awesome.md <==
# Awesome CRI-O [![Awesome](https://awesome.re/badge.svg)](https://awesome.re)

This list follows the [awesome
manifesto](https://github.com/sindresorhus/awesome/blob/master/awesome.md), and
collects useful resources about CRI-O.

## Contents

- [Resources](#resources)
  - [Articles](#articles)
  - [Community](#community)
  - [Videos](#videos)
  - [Podcasts](#podcasts)
  - [Tutorials](#tutorials)
  - [Websites](#websites)

## Resources

### Articles

- [Under the hood of CRI-O (Oct 30, 2019)](https://vmblog.com/archive/2019/10/30/under-the-hood-of-cri-o-kubernetes-container-runtime.aspx)
- [Demystifying Containers – Part II: Container Runtimes (Jul 15, 2019)](https://www.cncf.io/blog/2019/07/15/demystifying-containers-part-ii-container-runtimes)
- [Red Hat contributes CRI-O to the Cloud Native Computing Foundation (Apr 8, 2019)](https://www.redhat.com/en/blog/red-hat-contributes-cri-o-cloud-native-computing-foundation)
- [Welcome to the CNCF, CRI-O! (Apr 8, 2019)](https://www.suse.com/c/welcome-to-the-cncf-cri-o)
- [Technical Deep-Dive of Container Runtimes (Feb 27, 2019)](https://www.suse.com/c/technical-deep-dive-of-container-runtimes)
- [CRI-O is now our default container runtime interface (Sep 17, 2018)](https://kubic.opensuse.org/blog/2018-09-17-crio-default)
- [CRI-O Container Runtime on SUSE CaaS Platform 3 (Jul 16, 2018)](https://www.suse.com/c/cri-o-container-runtime-on-suse-caas-platform-3)
- [6 Reasons why CRI-O is the best runtime for Kubernetes (Jun 6, 2017)](https://www.projectatomic.io/blog/2017/06/6-reasons-why-cri-o-is-the-best-runtime-for-kubernetes)

### Community

- [Kubernetes Slack #cri-o](https://slack.com/app_redirect?channel=CAZH62UR1)
- [Freenode IRC #cri-o](https://webchat.freenode.net)

### Podcasts

- [PodCTL #12 - Introduction to CRI-O (Oct 30, 2017)](https://podctl.com/an-introduction-to-cri-o)

### Videos

- [CRI-O: Under the Hood (Nov 20, 2019)](https://www.youtube.com/watch?v=3kz-pERV6Qg)
- [Introduction to CRI-O (Nov 19, 2019)](https://www.youtube.com/watch?v=V53nSS2mnsM)
- [CRI-O: All the Runtime Kubernetes Needs (Dec 15, 2017)](https://www.youtube.com/watch?v=NVa8xR4Eyj8)

### Tutorials

- [CRI-O + Container Linux: How to Install (Apr 20, 2019)](https://edenmal.moe/post/2018/CRI-O-Container-Linux-How-to-Install)
- [CentOS 7 with CRI-O on EKS (Nov 20, 2018)](https://medium.com/errnothxbye/centos-7-with-cri-o-on-eks-ae9684aff764)

### Websites

- [cri-o.io (official website)](https://cri-o.io/)

==> cri-o-1.22.1-1-aarch64.pkg.tar.xz: usr/share/doc/cri-o/awesome.md <==
# Awesome CRI-O [![Awesome](https://awesome.re/badge.svg)](https://awesome.re)

This list follows the [awesome
manifesto](https://github.com/sindresorhus/awesome/blob/master/awesome.md), and
collects useful resources about CRI-O.

## Contents

- [Resources](#resources)
  - [Articles](#articles)
  - [Community](#community)
  - [Videos](#videos)
  - [Podcasts](#podcasts)
  - [Tutorials](#tutorials)
  - [Websites](#websites)

## Resources

### Articles

- [Under the hood of CRI-O (Oct 30, 2019)](https://vmblog.com/archive/2019/10/30/under-the-hood-of-cri-o-kubernetes-container-runtime.aspx)
- [Demystifying Containers – Part II: Container Runtimes (Jul 15, 2019)](https://www.cncf.io/blog/2019/07/15/demystifying-containers-part-ii-container-runtimes)
- [Red Hat contributes CRI-O to the Cloud Native Computing Foundation (Apr 8, 2019)](https://www.redhat.com/en/blog/red-hat-contributes-cri-o-cloud-native-computing-foundation)
- [Welcome to the CNCF, CRI-O! (Apr 8, 2019)](https://www.suse.com/c/welcome-to-the-cncf-cri-o)
- [Technical Deep-Dive of Container Runtimes (Feb 27, 2019)](https://www.suse.com/c/technical-deep-dive-of-container-runtimes)
- [CRI-O is now our default container runtime interface (Sep 17, 2018)](https://kubic.opensuse.org/blog/2018-09-17-crio-default)
- [CRI-O Container Runtime on SUSE CaaS Platform 3 (Jul 16, 2018)](https://www.suse.com/c/cri-o-container-runtime-on-suse-caas-platform-3)
- [6 Reasons why CRI-O is the best runtime for Kubernetes (Jun 6, 2017)](https://www.projectatomic.io/blog/2017/06/6-reasons-why-cri-o-is-the-best-runtime-for-kubernetes)

### Community

- [Kubernetes Slack #cri-o](https://slack.com/app_redirect?channel=CAZH62UR1)

### Podcasts

- [PodCTL #12 - Introduction to CRI-O (Oct 30, 2017)](https://podctl.buzzsprout.com/110399/585611-an-introduction-to-cri-o)

### Videos

- [CRI-O: Deep Diving into the Security (Aug 19, 2020)](https://youtu.be/RoiIx8mcECY)
- [CRI-O: Development Process & How to Contribute (Aug 18, 2020)](https://youtu.be/0MB5tUT4u3Q)
- [CRI-O: Under the Hood (Nov 20, 2019)](https://www.youtube.com/watch?v=3kz-pERV6Qg)
- [Introduction to CRI-O (Nov 19, 2019)](https://www.youtube.com/watch?v=V53nSS2mnsM)
- [CRI-O: All the Runtime Kubernetes Needs (Dec 15, 2017)](https://www.youtube.com/watch?v=NVa8xR4Eyj8)

### Tutorials

- [CRI-O + Container Linux: How to Install (Apr 20, 2019)](https://edenmal.moe/post/2018/CRI-O-Container-Linux-How-to-Install)
- [CentOS 7 with CRI-O on EKS (Nov 20, 2018)](https://medium.com/errnothxbye/centos-7-with-cri-o-on-eks-ae9684aff764)

### Websites

- [cri-o.io (official website)](https://cri-o.io/)
